@@ -803,6 +803,40 @@ class TestNetworkElement(unittest.TestCase):
 
         self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], 'ap')])
         
+    def test_http_credentials_4(self):
+        """Test that Mikrotik credentials can be configured."""
+        cfg = {
+            'http_port': [12345, 80],
+            'credentials': [{'username': 'user', 'password': 'pass', 'role': 'ap'}],
+            'mikrotik_username': 'mikrotik_user',
+            'mikrotik_password': 'mikrotik_pass',
+        }
+        # create a new registry object to pick up the config
+        self._await(self.reg.close())
+        self.reg = NetworkElementRegistry(self.ctx, cfg)
+        self.reg.ne_type = 'ap'
+
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+
+        self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], 'ap'), HttpCredentials('mikrotik_user', 'mikrotik_pass', [], 'router')])
+
+    def test_http_credentials_5(self):
+        """Test that Mikrotik credentials will not be configured when username and password pair exists."""
+        cfg = {
+            'http_port': [12345, 80],
+            'credentials': [{'username': 'user', 'password': 'pass', 'role': 'router'}],
+            'mikrotik_username': 'user',
+            'mikrotik_password': 'pass',
+        }
+        # create a new registry object to pick up the config
+        self._await(self.reg.close())
+        self.reg = NetworkElementRegistry(self.ctx, cfg)
+        self.reg.ne_type = 'ap'
+
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+
+        self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], 'router')])
+
     def test_send_update_1(self):
         """Verify that send_update sends network_element_update_msg when matching elem_discovery
             reference is found."""
